@@ -1,5 +1,5 @@
 
-from .coco import (
+from .sync import (
     exchange,
     ConversationalComponent,
     generate_session_id,
